qpformat
========

|PyPI Version| |Tests Status| |Coverage Status| |Docs Status|


**qpformat** is a Python library for opening quantitative phase imaging
data file formats.


Documentation
-------------

The documentation, including the reference and examples, is available at
`qpformat.readthedocs.io <https://qpformat.readthedocs.io/en/stable/>`__.


Installation
------------

::

    pip install qpformat


Testing
-------

::

    pip install -e .
    pip install pytest
    pytest tests
    

.. |PyPI Version| image:: https://img.shields.io/pypi/v/qpformat.svg
   :target: https://pypi.python.org/pypi/qpformat
.. |Tests Status| image:: https://img.shields.io/github/workflow/status/RI-Imaging/qpformat/Checks
   :target: https://github.com/RI-Imaging/qpformat/actions?query=workflow%3AChecks
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/RI-imaging/qpformat/master.svg
   :target: https://codecov.io/gh/RI-imaging/qpformat
.. |Docs Status| image:: https://readthedocs.org/projects/qpformat/badge/?version=latest
   :target: https://readthedocs.org/projects/qpformat/builds/

